<?php
/*
Plugin Name: Gravity Forms GEO Fields Add-on
Plugin URI: http://www.geomywp.com 
Description: Add GEO location to posts from the front end using Gravity Forms
Author: Eyal Fitoussi
Version: 1.3
Author URI: http://www.geomywp.com 
*/

function ggf_init() {
	//define globals
	define('GGF_URL', plugins_url() . '/gravity-forms-geo-fields/');
	define('GGF_PATH', plugin_dir_path(dirname(__FILE__)) . 'gravity-forms-geo-fields/');
	
	//Load language
	load_plugin_textdomain('GGF', FALSE, dirname(plugin_basename(__FILE__)).'/languages/');

	//when in admin page
	if ( is_admin() ) {
		//activate our add-on
		$gmw_plugins = get_option('wppl_plugins');
		//print_r($gmw_plugins);
		if ( isset($gmw_plugins) && !empty($gmw_plugins) )
			 $gmw_plugins['gravity_forms'] = 'gravity_forms';
		else
			$gmw_plugins = array( 'gravity_forms' => 'gravity_forms');
		
		update_option('wppl_plugins', $gmw_plugins );
		//get gmw options
		if ( !function_exists('gmw_loaded') ) :

			//define remote site
			define( 'GMW_REMOTE_SITE_URL', 'https://geomywp.com' );
			/*
			 * include plugin updater. There is a conflict between GEO my WP and GGF. happens only when GGF is already activated and 
			 * and in the moment taht activating GEO my WP. So we simply check that we do not include the below functions and file
			 * when the activate plugin action is running
			 */
			if ( isset($_GET['action']) && $_GET['action'] == 'activate' ) {
				//nothing here
			} else {
				//include plugin's updater file
				include_once GGF_PATH .'admin/ggf-updater.php';
			}
			
			//add menu item to "Forms" Menu
			function ggf_menu_item($menu_items){
				$menu_items[] = array("name" => "ggf_submenu", "label" => __('GEO Fields','GGF'), "callback" => "gmw_premium_license_page", "permission" => "edit_posts");
				return $menu_items;
			}
			add_filter("gform_addon_navigation", "ggf_menu_item");
			
		endif;
		
		//get license keys
		$gmw_license_keys = get_option( 'gmw_license_keys' );
		// Check plugin's license key
		if ( isset( $gmw_license_keys['gravity_forms'] )  ) :
			$license = trim($gmw_license_keys['gravity_forms']);
				
			$gmw_updater = new GMW_Premium_Plugin_Updater( GMW_REMOTE_SITE_URL, __FILE__, array(
				'version' 	=> '1.3',
				'license' 	=> $license,
				'item_name' => 'Gravity Forms',
				'author' 	=> 'Eyal Fitoussi'
			));
		endif;
		
		//Disactivate license key when deactivating the add-on 
		function deactivate_ggf() {
			$gmw_on = get_option('wppl_plugins');
			$add_on = 'gravity_forms';
			
			// deactivate add-on in add-ons page
			if ( isset($gmw_on[$add_on]) ) :
				unset($gmw_on[$add_on]);
				update_option( 'wppl_plugins',$gmw_on );
			endif;
			
			//deactivate license key
			$licenses = get_option( 'gmw_license_keys' );
			
			if ( isset($add_on) ) :
			
				$this_license = trim( $licenses[$add_on]);
				$this_name = ucwords(str_replace('_', ' ', $add_on));
				
				$api_params = array( 
					'edd_action'=> 'deactivate_license', 
					'license' 	=> $this_license, 
					'item_name' => urlencode( $this_name ) // the name of our product in EDD
				);
				
				// Call the custom API.
				$response = wp_remote_get( add_query_arg( $api_params, GMW_REMOTE_SITE_URL ), array( 'timeout' => 15, 'sslverify' => false ) );
		
				// make sure the response came back okay
				if ( is_wp_error( $response ) )
					return false;
		
				// decode the license data
				$license_data = json_decode( wp_remote_retrieve_body( $response ) );
				
				// $license_data->license will be either "deactivated" or "failed"
				$statuses = get_option( 'gmw_premium_plugin_status' );
				
				if( $license_data->license == 'deactivated' ) :
					unset($statuses[$add_on]);
					update_option( 'gmw_premium_plugin_status',$statuses );
				endif;
					//delete_option( 'gmw_premium_plugin_status' );
			endif;
		}
		register_deactivation_hook(__file__, 'deactivate_ggf');
		
		//include settings for form settings page
		include_once GGF_PATH . 'admin/admin-settings-page.php';
		//include settings for form editor page
		include_once GGF_PATH . 'admin/admin-editor-page.php';
		//include GGF user registration setting  page
		if ( class_exists('GFUser') ) include_once GGF_PATH . 'admin/admin-user-registration.php';
	} else {
		//register script and styles
		function ggf_register_scripts() {
			wp_register_script( 'ggf-js',  GGF_URL . 'js/gf.js',array(),false,true );
			wp_register_style( 'ggf-style', GGF_URL . 'css/style.css' );
			wp_register_script( 'google-maps', 'http://maps.googleapis.com/maps/api/js?sensor=false',array(),false);
		}
		add_action( 'wp_enqueue_scripts', 'ggf_register_scripts' );
		//include functions page
		include_once GGF_PATH . 'includes/functions.php';
	}
}
add_action( 'plugins_loaded', 'ggf_init' );