<?php
/**
 * GGF function - geocode address
 * @since 1.2
 */
function ggf_geocode_location($fAddress, $latLng) {

 	$returned_address = array();
	$ch = curl_init();	
    
    // GET THE XML FILE WITH RESUALTS
    curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
	curl_setopt($ch, CURLOPT_USERAGENT, "Mozilla/2.0 (compatible; MSIE 3.02; Update a; AK; Windows 95)");
	curl_setopt($ch, CURLOPT_HTTPGET, true);
	
	if ( !isset($latLng) || empty($latLng) ) {
		 // MAKE SURE ADDRES DOENST HAVE ANY CHARACTERS THAT GOOGLE CANNOT READ 
		$rip_it = array( " " => "+", "," => "", "?" => "", "&" => "", "=" => "" , "#" => "");
    	$address = str_replace(array_keys($rip_it), array_values($rip_it), $fAddress);
    
		curl_setopt($ch, CURLOPT_URL, "http://maps.googleapis.com/maps/api/geocode/xml?address=". $address."&sensor=false"  );
	} else {
		curl_setopt($ch, CURLOPT_URL, 'http://maps.google.com/maps/api/geocode/xml?latlng='.$latLng['lat'].','.$latLng['lng'].'&sensor=false');
	}
	
	curl_setopt($ch, CURLOPT_CONNECTTIMEOUT, 60);
	$got_xml = curl_exec($ch);
  
    // PARSE THE XML FILE 
    $xml = false;
	$xml = new SimpleXMLElement($got_xml);

	if ( $xml->status == 'OK' ) :

		//GET THE LATITUDE/LONGITUDE FROM THE XML FILE 
		$returned_address['lat']  = esc_attr( $xml->result->geometry->location->lat );
		$returned_address['long'] = esc_attr( $xml->result->geometry->location->lng );
		
		$returned_address['formatted_address'] = esc_attr($xml->result->formatted_address);
		$address_array = $xml->result->address_component;
		
		if ( isset($address_array) && !empty($address_array) ) :
			$returned_address['street'] 	   = false;
			$returned_address['apt'] 		   = false;
			$returned_address['city'] 		   = false;
			$returned_address['state']  	   = false;
			$returned_address['state_long']    = false;
			$returned_address['zipcode'] 	   = false;
			$returned_address['country'] 	   = false;
			$returned_address['country_long']  = false;
			
			foreach ($address_array as $ac) :
				if ( $ac->type == 'street_number' ) :
					$street_number = esc_attr($ac->long_name); 
				endif;
				
				if ($ac->type == 'route') :
					$street_f = esc_attr($ac->long_name); 
					if ( isset( $street_number )  && !empty( $street_number ) )	
						$returned_address['street'] = $street_number . ' ' . $street_f;
					else
						$returned_address['street'] = $street_f;
				endif;
				
				if ($ac->type == 'subpremise') 
					$returned_address['apt'] = esc_attr($ac->long_name); 
				
				if ($ac->type == 'locality') 
					$returned_address['city'] = esc_attr($ac->long_name); 
	
				if ($ac->type == 'administrative_area_level_1') :
					$returned_address['state'] = esc_attr($ac->short_name); 
					$returned_address['state_long'] = esc_attr($ac->long_name);
				endif;
				
				if ($ac->type == 'postal_code') 
					$returned_address['zipcode'] = esc_attr($ac->long_name); 
				
				if ($ac->type == 'country') :
					$returned_address['country'] = esc_attr($ac->short_name); 
					$returned_address['country_long'] = esc_attr($ac->long_name);
				endif;	
			endforeach;
		endif;
		return $returned_address;
	endif;
}

/**
 * GGF function - execute function on form load
 * @param unknown_type $form
 * @return unknown|string
 */
function ggf_render_form($form) {
	?>
	<script type="text/javascript">
	    jQuery(document).bind('gform_post_render', function(){
	        
    		autocomplete_init();
    		if( jQuery('#ggf-map').length ) {
    			gmaps_init();
    	    };
    	});	
	</script>
	<?php 
	
	$ggfOptions = $form['ggf_settings'];
	
	if ( !isset($ggfOptions['address_fields']['use']) || $ggfOptions['address_fields']['use'] == 0 ) return $form;
	
	wp_enqueue_script( 'ggf-js');
	wp_enqueue_script( 'jquery-ui-autocomplete');
	wp_localize_script( 'ggf-js', 'autoComp', '.ggf-autocomplete input' );
	wp_localize_script( 'ggf-js', 'ggfFullAddress', '.ggf-full-address input' );
	wp_enqueue_style( 'ggf-style');
	wp_enqueue_script( 'google-maps' );
		
	foreach ( $form['fields'] as $key => $field ) {
		if ( isset($field['ggf_fields']) && $field['ggf_fields'] == 'address' ) {
			$ac = ( isset($field['ggf-autocomplete']) && $field['ggf-autocomplete'] == 1 ) ? ' ggf-autocomplete' : '';
			$form['fields'][$key]['cssClass'] .= ' ggf-full-address '.$ac;
		}
	}
	
	return $form;
}
add_filter("gform_pre_render", "ggf_render_form");


/**
 * GMW GF function - Display map
 */
function ggf_field_input( $input, $field, $value, $lead_id, $form_id ){
		
	$form = RGFormsModel::get_form_meta_by_id($form_id);
	$gffSettings = $form[0]['ggf_settings'];
	
	if ( $field["type"] == "ggfMap" && isset($gffSettings['address_fields']['use']) && $gffSettings['address_fields']['use'] == 1 ) {
		
		if ( !IS_ADMIN ) :
	
			// set map's size
			$map_width = ( isset( $field['ggf-map-width'] ) && !empty( $field['ggf-map-width'] ) ) ? $field['ggf-map-width'] : "300px";
			$map_height = ( isset( $field['ggf-map-height'] ) && !empty( $field['ggf-map-height'] ) ) ? $field['ggf-map-height'] : "300px";
			
			if ( isset($_POST['ggf_lat']) && !empty( $_POST['ggf_lat'] ) ) {
				$latitude = $_POST['ggf_lat'];
			} elseif ( isset( $field['ggf-map-latitude'] ) && !empty( $field['ggf-map-latitude'] ) ) {
				$latitude = $field['ggf-map-latitude']; 
			} else {
				$latitude = '40.7827096';
			}
			
			if ( isset($_POST['ggf_lng']) && !empty( $_POST['ggf_lng'] ) ) {
				$longitude = $_POST['ggf_lng'];
			} elseif ( isset( $field['ggf-map-longitude'] ) && !empty( $field['ggf-map-longitude'] ) ) {
				$longitude = $field['ggf-map-longitude'];
			} else {
				$longitude = '-73.965309';
			}
			
			$mapArgs = array (
				'latitude' 	=> $latitude,
				'longitude' => $longitude
			);
			
			wp_localize_script( 'ggf-js', 'mapArgs', $mapArgs );
	
			$input = '
			<div id="ggf-map-wrapper" class="ggf-map-wrapper ggf-map-wrapper">
				<div id="ggf-map" class="ggf-map" style="height:'.$map_height.';width:'.$map_width.'"></div>
				<input type="hidden" class="ggf-lat" name="ggf_lat" value="'.$latitude.'" />
				<input type="hidden" class="ggf-lng" name="ggf_lng" value="'.$longitude.'" />
			</div><!-- map holder -->';	
		endif;
	}	

	return $input;
}
add_filter( "gform_field_input" , "ggf_field_input", 23, 5 );

/**
 * GEO my WP GF - Update location to post when form submitted
 */
function ggf_add_location($entry, $form) {
	
	$ggfSettings = $form['ggf_settings'];
	if ( !isset( $ggfSettings['address_fields']['use'] ) || $ggfSettings['address_fields']['use'] == 0 ) return;
		
	$postID 		 = $entry['post_id'];
	$org_location 	 = array();
	$additional_info = array(
				'phone'   => '',
				'fax' 	  => '',
				'email'   => '',
				'website' => ''
			);
	
	if ( !isset( $ggfSettings['address_fields']['use'] ) || $ggfSettings['address_fields']['use'] == 0 ) return;
	
	//when single address field
	if ( isset( $ggfSettings['address_fields']['use'] ) && $ggfSettings['address_fields']['use'] == 1 ) {

		//find the address field and get its value
		foreach ( $form['fields'] as $field ) {
			
			if ( isset($field['ggf_fields']) && $field['ggf_fields'] == 'address' ) {
				$fAddress = $_POST['input_'.$field['id']];
			}
			if ( isset( $ggfSettings['address_fields']['gmw']['use'] ) && $ggfSettings['address_fields']['gmw']['use'] == 1 ) {
	
				if( isset($field['ggf_fields']) && $field['ggf_fields'] == 'phone' ) {
					$additional_info['phone'] =  $_POST['input_'.$field['id']];
				} 
				if( isset($field['ggf_fields']) && $field['ggf_fields'] == 'fax' ) {
					$additional_info['fax'] =  $_POST['input_'.$field['id']];
				}
				if( isset($field['ggf_fields']) && $field['ggf_fields'] == 'email' ) {
					$additional_info['email'] =  $_POST['input_'.$field['id']];
				}
				if( isset($field['ggf_fields']) && $field['ggf_fields'] == 'website' ) {
					$additional_info['website'] =  $_POST['input_'.$field['id']];
				}
			}
		}
		
		//geocode the address
		$ggfLocation = ggf_geocode_location($fAddress, false);
		//get location information into arrat
		$ggfLocation['address'] = $fAddress;
		
		$org_location['street']  = $ggfLocation['street'];
		$org_location['apt'] 	 = $ggfLocation['apt'];
		$org_location['city'] 	 = $ggfLocation['city'];
		$org_location['state']   = $ggfLocation['state'];
		$org_location['zipcode'] = $ggfLocation['zipcode'];
		$org_location['country'] = $ggfLocation['country'];
		
		$ggfLocation['org_location'] = $org_location;
	
	//when using multiple fields
	} else {
		
		//get fields value
		foreach ( $form['fields'] as $field ) {

			if( isset($field['ggf_fields']) && $field['ggf_fields'] == 'street' ) {
				$org_location['street'] =  $_POST['input_'.$field['id']];
			}
			if( isset($field['ggf_fields']) && $field['ggf_fields'] == 'apt' ) {
				$org_location['apt'] =  $_POST['input_'.$field['id']];
			}
			if( isset($field['ggf_fields']) && $field['ggf_fields'] == 'city' ) {
				$org_location['city'] =  $_POST['input_'.$field['id']];
			}
			if( isset($field['ggf_fields']) && $field['ggf_fields'] == 'state' ) {
				$org_location['state'] =  $_POST['input_'.$field['id']];
				//$updateFields['state'] =  $field['postCustomFieldName'];
			}
			if( isset($field['ggf_fields']) && $field['ggf_fields'] == 'zipcode' ) {
				$org_location['zipcode'] =  $_POST['input_'.$field['id']];
			}
			if( isset($field['ggf_fields']) && $field['ggf_fields'] == 'country' ) {
				$org_location['country'] =  $_POST['input_'.$field['id']];
				//$updateFields['country'] =  $field['postCustomFieldName'];
			}
			
			if ( isset( $ggfSettings['address_fields']['gmw']['use'] ) && $ggfSettings['address_fields']['gmw']['use'] == 1 ) {
				
				if( isset($field['ggf_fields']) && $field['ggf_fields'] == 'phone' ) 
					$additional_info['phone'] =  $_POST['input_'.$field['id']];
				
				if( isset($field['ggf_fields']) && $field['ggf_fields'] == 'fax' ) 
					$additional_info['fax'] =  $_POST['input_'.$field['id']];
						
				if( isset($field['ggf_fields']) && $field['ggf_fields'] == 'email' ) 
					$additional_info['email'] =  $_POST['input_'.$field['id']];
			
				if( isset($field['ggf_fields']) && $field['ggf_fields'] == 'website' ) 
					$additional_info['website'] =  $_POST['input_'.$field['id']];
			}
		}
		
		$org_location_geocode = $org_location;
		unset( $org_location_geocode['apt'] );
		//save the original address entered
		$ggfLocation  = ggf_geocode_location(implode(' ', $org_location_geocode), false);
		
		$ggfLocation['org_location'] = $org_location;
		$ggfLocation['address'] 	 = implode(' ', $org_location);
	}
	
	$custom_fields = ( isset($ggfSettings['address_fields']['fields']) && !empty($ggfSettings['address_fields']['fields']) ) ? $ggfSettings['address_fields']['fields'] : array();
	
	//save location to user meta
	foreach ( $custom_fields as $key => $value ) {
		if ( $key == 'street' ) {
			if ( isset($ggfLocation['org_location']['street']) && !empty($ggfLocation['org_location']['street']) ) {
				update_post_meta($postID, $value, $ggfLocation['org_location']['street'] );
			} else {
				update_post_meta($postID, $value, $ggfLocation['street'] );
				$ggfLocation['org_location']['street'] = $ggfLocation['street'];
			}
		} elseif ( $key == 'apt' ) {
			if ( isset($ggfLocation['org_location']['apt']) && !empty($ggfLocation['org_location']['apt']) ) {
				update_post_meta($postID, $value, $ggfLocation['org_location']['apt'] );
			} else {
				update_post_meta($postID, $value, $ggfLocation['apt'] );
				$ggfLocation['org_location']['apt'] = $ggfLocation['apt'];
			}
		} elseif ( $key == 'city' ) {
			if ( isset($ggfLocation['org_location']['city']) && !empty($ggfLocation['org_location']['city']) ) {
				update_post_meta($postID, $value, $ggfLocation['org_location']['city'] );
			} else {
				update_post_meta($postID, $value, $ggfLocation['city'] );
				$ggfLocation['org_location']['city'] = $ggfLocation['city'];
			}
		} elseif ( $key == 'zipcode' ) {
			if ( isset($ggfLocation['org_location']['zipcode']) && !empty($ggfLocation['org_location']['zipcode']) ) {
				update_post_meta($postID, $value, $ggfLocation['org_location']['zipcode'] );
			} else {
				update_post_meta($postID, $value, $ggfLocation['zipcode'] );
				$ggfLocation['org_location']['zipcode'] = $ggfLocation['zipcode'];
			}
		} else {
			if ( isset($ggfLocation[$key]) && !empty($ggfLocation[$key]) ) update_post_meta($postID, $value, $ggfLocation[$key] );
		}
	}
	
	//if ( isset( $ggfLocation['state'] ) && !empty( $ggfLocation['state'] ) && isset( $updateFields['state']) ) update_post_meta($postID, $updateFields['state'], $ggfLocation['state']);
	//if ( isset( $ggfLocation['country'] ) && !empty( $ggfLocation['country'] ) && isset( $updateFields['country'] ) ) update_post_meta($postID, $updateFields['country'], $ggfLocation['country']);
	
	//update custom fields
	//foreach ( $ggfSettings['address_fields']['fields'] as $key => $field ) {	
		//if ( isset($field) && !empty($field) && isset($ggfLocation[$key]) && !empty($ggfLocation[$key]) ) update_post_meta($postID, $field, $ggfLocation[$key]);
	//}
	
	do_action('ggf_after_location_geocoded', $postID, $entry, $form, $ggfLocation, $additional_info);
	
}
add_action('gform_post_submission', 'ggf_add_location', 5, 2);

//updated GEO my WP custom fields and database
function ggf_update_gmw_posts_location($postID, $entry, $form, $ggfLocation, $additional_info) {
	
	$ggfSettings = $form['ggf_settings'];
	if ( !isset( $ggfSettings['address_fields']['gmw']['use'] ) || $ggfSettings['address_fields']['gmw']['use'] == 0 || !function_exists('gmw_loaded') ) return;
		
	update_post_meta($postID, '_wppl_street', $ggfLocation['org_location']['street']);
	update_post_meta($postID, '_wppl_apt', $ggfLocation['org_location']['apt']);
	update_post_meta($postID, '_wppl_city', $ggfLocation['org_location']['city']);
	update_post_meta($postID, '_wppl_state', $ggfLocation['state']);
	update_post_meta($postID, '_wppl_state_long', $ggfLocation['state_long']);
	update_post_meta($postID, '_wppl_zipcode', $ggfLocation['org_location']['zipcode']);
	update_post_meta($postID, '_wppl_country', $ggfLocation['country']);
	update_post_meta($postID, '_wppl_country_long', $ggfLocation['country_long']);
	update_post_meta($postID, '_wppl_address', $ggfLocation['address']);
	update_post_meta($postID, '_wppl_formatted_address', $ggfLocation['formatted_address']);
	update_post_meta($postID, '_wppl_lat', $ggfLocation['lat']);
	update_post_meta($postID, '_wppl_long', $ggfLocation['long']);
	update_post_meta($postID, '_wppl_address', $ggfLocation['address']);
	
	update_post_meta($postID, '_wppl_phone', $additional_info['phone']);
	update_post_meta($postID, '_wppl_fax', $additional_info['fax']);
	update_post_meta($postID, '_wppl_email', $additional_info['email']);
	update_post_meta($postID, '_wppl_website', $additional_info['website']);
	
	//Save information to database
	global $wpdb;
	$wpdb->replace( $wpdb->prefix . 'places_locator',
		array(
			'post_id'			=> $postID,
			'feature'  			=> 0,
			'post_type' 		=> get_post_type($postID),
			'post_title' 		=> get_the_title($postID),
			'post_status'		=> 'publish',
			'street' 			=> $ggfLocation['org_location']['street'],
			'apt' 				=> $ggfLocation['org_location']['apt'],
			'city' 				=> $ggfLocation['org_location']['city'],
			'state' 			=> $ggfLocation['state'],
			'state_long' 		=> $ggfLocation['state_long'],
			'zipcode' 			=> $ggfLocation['zipcode'],
			'country' 			=> $ggfLocation['country'],
			'country_long' 		=> $ggfLocation['country_long'],
			'address' 			=> $ggfLocation['address'],
			'formatted_address' => $ggfLocation['formatted_address'],
			'phone' 			=> $additional_info['phone'],
			'fax' 				=> $additional_info['fax'],
			'email' 			=> $additional_info['email'],
			'website' 			=> $additional_info['website'],
			'lat' 				=> $ggfLocation['lat'],
			'long' 				=> $ggfLocation['long'],
			'map_icon'  		=> '_default.png',
		)
	);
}
add_action('ggf_after_location_geocoded','ggf_update_gmw_posts_location', 10, 5);

/**
 * GEO my WP function - Update users location using "User registration" gravity forms add-on
 */
function ggf_add_user_location_after_registration($user_id, $config, $entry, $user_pass) {

	//get form details
	$form = RGFormsModel::get_form_meta_by_id($config['form_id']);
	$form = $form[0];
	//get options
	$ggfSettings = $form['ggf_settings'];
	//get GEO user registration fields
	$ggfURSettings = $config['meta']['ggf_settings'];
	
	if ( !isset( $ggfSettings['address_fields']['use'] ) || $ggfSettings['address_fields']['use'] == 0 ) return;
		
	//when single address field
	if ( isset( $ggfSettings['address_fields']['use'] ) && $ggfSettings['address_fields']['use'] == 1 ) {

		//find the address field and get its value
		foreach ( $form['fields'] as $field ) if ( isset($field['ggf_fields']) && $field['ggf_fields'] == 'address' ) $address = $_POST['input_'.$field['id']];
		
		//geocode the address
		$ggfLocation = ggf_geocode_location($address, false);
		
		//get location information into arrat
		$ggfLocation['address'] = $address;
		
		$org_location['street']  = $ggfLocation['street'];
		$org_location['apt'] 	 = $ggfLocation['apt'];
		$org_location['city'] 	 = $ggfLocation['city'];
		$org_location['state']   = $ggfLocation['state'];
		$org_location['zipcode'] = $ggfLocation['zipcode'];
		$org_location['country'] = $ggfLocation['country'];
		
		$ggfLocation['org_location'] = $org_location;

	} else {
		
		foreach ( $form['fields'] as $field ) {
			
			if( isset($field['ggf_fields']) && $field['ggf_fields'] == 'street' ) {
				$org_location['street'] =  $_POST['input_'.$field['id']];
			}
			if( isset($field['ggf_fields']) && $field['ggf_fields'] == 'apt' ) {
				$org_location['apt'] =  $_POST['input_'.$field['id']];
			}
			if( isset($field['ggf_fields']) && $field['ggf_fields'] == 'city' ) {
				$org_location['city'] =  $_POST['input_'.$field['id']];
			}
			if( isset($field['ggf_fields']) && $field['ggf_fields'] == 'state' ) {
				$org_location['state'] =  $_POST['input_'.$field['id']];
			}
			if( isset($field['ggf_fields']) && $field['ggf_fields'] == 'zipcode' ) {
				$org_location['zipcode'] =  $_POST['input_'.$field['id']];
			}
			if( isset($field['ggf_fields']) && $field['ggf_fields'] == 'country' ) {
				$org_location['country'] =  $_POST['input_'.$field['id']];
			}
			
		}
		
		$org_location_geocode = $org_location;
		unset( $org_location_geocode['apt'] );
		//save the original address entered
		$ggfLocation  = ggf_geocode_location(implode(' ', $org_location_geocode), false);
		
		$ggfLocation['org_location'] = $org_location;
		$ggfLocation['address'] 	 = implode(' ', $org_location);	
	}
	
	$user_meta_fields = ( isset($ggfURSettings['address_fields']['user_meta_fields']) && !empty($ggfURSettings['address_fields']['user_meta_fields']) ) ? $ggfURSettings['address_fields']['user_meta_fields'] : array();
	
	//save location to user meta
	foreach ( $user_meta_fields as $key => $value ) {
		if ( $key == 'street' ) {
			if ( isset($ggfLocation['org_location']['street']) && !empty($ggfLocation['org_location']['street']) )
				update_user_meta($user_id, $value, $ggfLocation['org_location']['street'] );
			else
				update_user_meta($user_id, $value, $ggfLocation['street'] );
		} elseif ( $key == 'apt' ) {
			if ( isset($ggfLocation['org_location']['apt']) && !empty($ggfLocation['org_location']['apt']) )
				update_user_meta($user_id, $value, $ggfLocation['org_location']['apt'] );
			else
				update_user_meta($user_id, $value, $ggfLocation['apt'] );
		} elseif ( $key == 'city' ) {
			if ( isset($ggfLocation['org_location']['city']) && !empty($ggfLocation['org_location']['city']) )
				update_user_meta($user_id, $value, $ggfLocation['org_location']['city'] );
			else
				update_user_meta($user_id, $value, $ggfLocation['city'] );
		} elseif ( $key == 'zipcode' ) {
			if ( isset($ggfLocation['org_location']['zipcode']) && !empty($ggfLocation['org_location']['zipcode']) )
				update_user_meta($user_id, $value, $ggfLocation['org_location']['zipcode'] );
			else
				update_user_meta($user_id, $value, $ggfLocation['zipcode'] );
		} else {
			if ( isset($ggfLocation[$key]) && !empty($ggfLocation[$key]) ) update_user_meta($user_id, $value, $ggfLocation[$key] );
		}
	}
	
	//check if buddypress activated
	if ( class_exists('BuddyPress') ) {

		//get the xprofile fiields
		$user_xprofile_fields = ( isset($ggfURSettings['address_fields']['bp_fields']) && !empty($ggfURSettings['address_fields']['bp_fields']) ) ? $ggfURSettings['address_fields']['bp_fields'] : array();
		
		//save location to xprofile fields
		foreach ( $user_xprofile_fields as $key => $value ) {
			if ( $key == 'street' ) {
				if ( isset($ggfLocation['org_location']['street']) && !empty($ggfLocation['org_location']['street']) )
					xprofile_set_field_data($value, $user_id, $ggfLocation['org_location']['street'] );
				else
					xprofile_set_field_data($value, $user_id, $ggfLocation['street'] );
			} elseif ( $key == 'apt' ) {
				if ( isset($ggfLocation['org_location']['apt']) && !empty($ggfLocation['org_location']['apt']) )
					xprofile_set_field_data($value, $user_id, $ggfLocation['org_location']['apt'] );
				else
					xprofile_set_field_data($value, $user_id, $ggfLocation['apt'] );
			} elseif ( $key == 'city' ) {
				if ( isset($ggfLocation['org_location']['city']) && !empty($ggfLocation['org_location']['city']) )
					xprofile_set_field_data($value, $user_id, $ggfLocation['org_location']['city'] );
				else
					xprofile_set_field_data($value, $user_id, $ggfLocation['city'] );
			} elseif ( $key == 'zipcode' ) {
				if ( isset($ggfLocation['org_location']['zipcode']) && !empty($ggfLocation['org_location']['zipcode']) )
					xprofile_set_field_data($value, $user_id, $ggfLocation['org_location']['zipcode'] );
				else
					xprofile_set_field_data($value, $user_id, $ggfLocation['zipcode'] );
			} else {
				if ( isset($ggfLocation[$key]) && !empty($ggfLocation[$key]) ) xprofile_set_field_data($value, $user_id, $ggfLocation[$key] );
			}
		}
	}
	
	//check if GEO my WP activated and we need to save locaiton to member
	if ( isset( $ggfURSettings['address_fields']['gmwbp']['use'] ) && $ggfURSettings['address_fields']['gmwbp']['use'] == 1 && function_exists('gmw_loaded') ) {
	
		$map_icon = ( isset($_POST['map_icon']) ) ? $_POST['map_icon'] : '_default.png';
	
		//save location into GEO my WP members table in database
		if ( isset($ggfLocation['lat']) && !empty($ggfLocation['lat']) ) {
			global $wpdb;
			$wpdb->replace('wppl_friends_locator', array(
					'member_id'			=> $user_id,
					'street'			=> $ggfLocation['org_location']['street'],
					'apt'				=> $ggfLocation['org_location']['apt'],
					'city' 				=> $ggfLocation['org_location']['city'],
					'state' 			=> $ggfLocation['state'],
					'state_long' 		=> $ggfLocation['state_long'],
					'zipcode'			=> $ggfLocation['zipcode'],
					'country' 			=> $ggfLocation['country'],
					'country_long'	 	=> $ggfLocation['country_long'],
					'address'			=> $ggfLocation['address'],
					'formatted_address' => $ggfLocation['formatted_address'],
					'lat'				=> $ggfLocation['lat'],
					'long'				=> $ggfLocation['long'],
					'map_icon'			=> $map_icon
			));
		} 
	}
	//hook and do something with the information
	do_action('ggf_after_member_location_saved', $user_id, $config, $entry, $user_pass, $ggfLocation);
}
add_action("gform_user_registered", "ggf_add_user_location_after_registration", 10, 4);
add_action("gform_user_updated", "ggf_add_user_location_after_registration", 10, 4);
?>